==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mount/translations/mount_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.ui" line="44"/>
        <source>Click to access this device from other applications.</source>
        <translation>Klicke um von anderen Anwendungen auf diesen Datenträger zugreifen zu können.</translation>
    </message>
    <message>
        <location filename="../menudiskitem.ui" line="57"/>
        <source>Click to eject this disc.</source>
        <translation>Klicke um den Datenträger auszuwerfen.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <location filename="../mountbutton.cpp" line="187"/>
        <source>Removable media/devices manager</source>
        <translation>Wechseldatenträger Manager</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="282"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Der Datenträger &lt;br&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/br&gt; ist verbunden.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="301"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Der Datenträger &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/br&gt; is entfernt.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="344"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is mounted to %2</source>
        <translation>Der Datenträger &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; ist eingehängt in %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="358"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is unmounted&lt;br&gt;
Now you can eject USB Flash or CD/DVD Disk.</source>
        <translation>Der Datenträger &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; ist ausgehängt&lt;br&gt;
Nun kann der USB Flash oder die CD/DVD Disk entfernt werden.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="390"/>
        <source>Can&apos;t mount device: %1&lt;br&gt;
%2</source>
        <translation>Kann %1 nicht einhängen&lt;br&gt;
%2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="396"/>
        <source>Device &apos;%1&apos; is mounted to %2</source>
        <translation>Datenträger &apos;%1&apos; ist eingehängt in %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="426"/>
        <source>Can&apos;t unmount device: %1&lt;br&gt;
%2</source>
        <translation>Kann Datenträger %1 nicht aushängen.&lt;br&gt;
%2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="430"/>
        <source>Device &apos;%1&apos; is unmounted</source>
        <translation>Datenträger &apos;%1&apos; ist nicht eingehängt</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="446"/>
        <source>No devices Available.</source>
        <translation>Kein Datenträger verfügbar.</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <location filename="../razormountconfiguration.ui" line="14"/>
        <source>Razor Removable media manager settings</source>
        <translation>Razor-Wechseldatenträger-Verwalter Einstellungen</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Verhalten</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="26"/>
        <source>When a device is connected </source>
        <translation>Wenn ein Datenträger angeschlossen ist</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="44"/>
        <source>Popup menu</source>
        <translation>Popup Menü</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="45"/>
        <source>Show info</source>
        <translation>Zeige Informationen</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="46"/>
        <source>Do nothing</source>
        <translation>Mach nichts</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mount/translations/mount_de_DE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_DE" version="2.0">
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>Klicke um von anderen Anwendungen auf diesen Datenträger zugreifen zu können.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>Klicke um den Datenträger auszuwerfen.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>Wechseldatenträger Manager</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Der Datenträger &lt;br&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/br&gt; ist verbunden.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Der Datenträger &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/br&gt; ist entfernt.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <source>No devices are available</source>
        <translation>Es sind keine Geräte verfügbar</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <source>Razor Removable media manager settings</source>
        <translation>Razor-Wechseldatenträger-Verwalter Einstellungen</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Verhalten</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>Wenn ein Datenträger angeschlossen ist</translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>Popup Menü</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>Zeige Informationen</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Mach nichts</translation>
    </message>
</context>
</TS>
